Byte string formatting
This module is analogous to the standard fmt module, but is
more limited in scope.
There is only one trait, Display, and formatting flags
are not currently supported.
However, bformat! is able to use the result of the standard macro
format_args! to produce formatted byte string.
ⓘ
bformat!("foo {}",
format_args!("{:x}", 255))Structs
- Argument
V1 - Represents a formatted argument.
- Arguments
- Represents a formatted string and set of arguments.
- Error
- Represents an error returned from a formatting trait
- Formatter
- Byte string formatter
- Parse
Error - Represents an error parsing a format string.
- Parser
- Parses a
&bstrformat string into a series ofItemcomponents.
Enums
- Item
- Represents a section of a parsed format string.
- Parse
Error Kind - Represents a kind of error generated while parsing a format string.
Traits
- Display
- Displays a value using a formatter.
- ToBString
- Creates a
BStringfrom a value. - Write
Fmt - Helper trait to support
Formatter::write_fmt
Functions
- format_
args - Formats an
Argumentsvalue into aBString.
Type Aliases
- Result
- The
Resulttype returned from thebfmtformatting trait.